@@ -1,4 +1,4 @@
-from gym.envs.registration import register
+from gymnasium.envs.registration import register
 
 register(
     id="RoomEnv-v0",
@@ -9,8 +9,3 @@ register(
     id="RoomEnv-v1",
     entry_point="room_env.envs:RoomEnv1",
 )
-
-register(
-    id="RoomEnv-v2",
-    entry_point="room_env.envs:RoomEnv2",
-)
