@@ -1,5 +1,5 @@
 """Room environment compatible with gym.
-I advise you to check out room2.py, as it's more general.
+I advise you to check out room1.py, as it's more general.
 """
 import json
 import logging
@@ -9,7 +9,7 @@ from copy import deepcopy
 from itertools import cycle
 from typing import Tuple
 
-import gym
+import gymnasium as gym
 
 from ..utils import read_lines, remove_name, split_name_entity
 
