@@ -1,6 +1,6 @@
 import unittest
 
-import gym
+import gymnasium as gym
 
 import room_env
 
